from sensor.Sensor import Sensor
from utils.datatypes import *
from utils import i18n

import time
import os
import libdesklets

class LTVCpu(Sensor):

	def __init__(self, count = "10", interval = "10", load = "white", snap = "1"):
		global _; _ = i18n.Translator("ltv-cpu-sensor")
		self.__load = []
		self.__snap = float(snap)
		Sensor.__init__(self)
		self._set_config_type("update", TYPE_INT,    int(interval))
		self._set_config_type("count",  TYPE_INT,    int(count))
		self._set_config_type("load",   TYPE_STRING, load)
		self.__model_name = libdesklets.cpu.get_model()
		self.__cpu_mhz = libdesklets.cpu.get_speed()
		self.__cache = libdesklets.cpu.get_cache_size()
		self._add_timer(0, self.cpu_loop)

	def get_configurator(self):
		configurator = self._new_configurator()
		configurator.set_name(_("CPU Graph"))
		configurator.add_title(_("Graph Configuration"))
		configurator.add_spin(_("Samples:"), "count", _("Number of samples to display in the graph."), 2, 40)
		configurator.add_spin(_("Update every (ds):"), "update", _("Updates the graph every x deciseconds."), 1, 600)
		configurator.add_color_selector(_("Graph Color:"), "load", _("Color used for the graph."))
		return configurator
	def __draw_line(self, color):
		output = "color " + color + ", polygon "
		count = float( len( self.__load ) - 1 )
		step = 0 
		for i in self.__load :
			x = str( 2.0 * step / count - 1.0 )
			y = str( i / 50.0 - 1.0 )
			if step == 0 :
				output = output + "-3 " + y + " "
			output = output + x + " " + y + " "
			if step == len( self.__load ) - 1 :
				output = output + "3 " + y + " 0 -3 0 "
			step = step + 1
		return output
	def draw(self):
		count = self._get_config("count")
		while len( self.__load ) < count :
			self.__load = [ 0 ] + self.__load
		while len( self.__load ) > count :
			self.__load = self.__load[ 1: ]
			
		load = libdesklets.cpu.get_load()[1]
			
		self.__load = self.__load[ 1: ] + [ load ]

		data = self._new_output()
		data.set("load", str(int(load))+"%")
		data.set("load_int", str(int(load)))
		data.set("load_float", str(float(load)))
		data.set("graph", "clear, " + self.__draw_line( self._get_config( "load" ) ) )
		data.set("model", self.__model_name)
		data.set("cpumhz", self.__cpu_mhz)
		data.set("cache", self.__cache)
		self._send_output(data)

	def cpu_loop(self):
		self.draw()
		self._add_timer(self._get_config("update")*100, self.cpu_loop)

def new_sensor(args): return apply(LTVCpu, args)
